@@ -104,6 +104,8 @@ class App:
 
         if default_middleware:
             self.add_middleware(DefaultMiddleware)
+        
+        self.static_test = StaticFile(static_dir)
 
         self.collections = []
 
@@ -122,7 +124,7 @@ class App:
     async def __call__(self, scope, recieve, send):
         if "static" in scope["path"]:
             # await self.static_app(scope, recieve, send)
-            await StaticFile(scope["path"])
+            await self.static_test(scope["path"])
 
         await self.middleware(scope, recieve, send)
 
