@@ -2,9 +2,14 @@ from starlette.responses import FileResponse
 import os
 
 
+class EmptyWSGI:
+    def __init__(self):
+        ...
+
+
 class StaticFile:
     def __init__(self, directory):
         self.directory = directory
     
     async def __call__(self, path: str):
-        return FileResponse(path)
\ No newline at end of file
+        return FileResponse(path, media_type="text/css")
\ No newline at end of file
